# Phase 1. Discover: Achieve Architecture Transparency
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/erp-transformation-discover#overview)
  * [Step 1. Model SAP LeanIX Fact Sheets and Build Your Repository](https://help.sap.com/docs/leanix/ea/erp-transformation-discover#step-1.-model-sap-leanix-fact-sheets-and-build-your-repository)
  * [Step 2. Scope ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation-discover#step-2.-scope-erp-transformation)
  * [Use Reports and Diagrams to Visualize the Transformation Scope](https://help.sap.com/docs/leanix/ea/erp-transformation-discover#use-reports-and-diagrams-to-visualize-the-transformation-scope)
  * [If Applicable: Additional Features and Views Leveraging SAP Reference Data](https://help.sap.com/docs/leanix/ea/erp-transformation-discover#if-applicable:-additional-features-and-views-leveraging-sap-reference-data)
  * [Advanced: TIME or 6R Assessment to Identify and Track Key Changes through the Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation-discover#advanced:-time-or-6r-assessment-to-identify-and-track-key-changes-through-the-transformation)
  * [Step 3. Report and Communicate](https://help.sap.com/docs/leanix/ea/erp-transformation-discover#step-3.-report-and-communicate)
  * [EA-Centric Dashboard and Reporting](https://help.sap.com/docs/leanix/ea/erp-transformation-discover#ea-centric-dashboard-and-reporting)
  * [Share Insights with Different Stakeholders](https://help.sap.com/docs/leanix/ea/erp-transformation-discover#share-insights-with-different-stakeholders)


Establish architecture transparency in ERP transformation. Understand and assess your 'as-is architecture' and report effectively.
